@@ -1,39 +1,30 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Pheanstalk\Contract;
 
-/**
- * A mockable wrapper around PHP "socket" or "file pointer" access.
- *
- * Only the subset of socket actions required by Pheanstalk are provided.
- *
- * @author  Paul Annesley
- */
+use Pheanstalk\Values\Timeout;
+
 interface SocketInterface
 {
     /**
      * Writes data to the socket.
-     *
-     * @param string $data
-     *
-     * @return void
      */
     public function write(string $data): void;
 
     /**
      * Reads up to $length bytes from the socket.
-     *
-     * @return string
+     * @param int<0, max> $length
      */
     public function read(int $length): string;
 
     /**
      * Reads up to the next new-line.
      * Trailing whitespace is trimmed.
-     *
-     * @param int
+     * @param Timeout|null $readTimeout
      */
-    public function getLine(): string;
+    public function getLine(?Timeout $readTimeout = null): string;
 
     /**
      * Disconnect the socket; subsequent usage of the socket will fail.
