@@ -1,12 +1,12 @@
 <?php
 
+declare(strict_types=1);
+
 namespace Pheanstalk\Exception;
 
 /**
  * An exception originating as a beanstalkd server error.
- *
- * @author  Paul Annesley
  */
-class ServerInternalErrorException extends ServerException
+final class ServerInternalErrorException extends ServerException
 {
 }
